Crate gta_img

Crate gta_img 

Library for reading from/writing to IMG archives (and supplementary DIR files) used throughout the 3D universe-era of Grand Theft Auto games.

Modules

error
Contains types for errors.
read
Contains types and the accompanying logic for reading from archives of different versions.
write
Contains types and the accompanying logic for writing to archives of different versions.

Constants

NAME_SIZE
Represents the maximum length of the name of an entry, excluding the null-terminator.
NULL_TERMINATOR
Represents the null terminator for the names of entries.
SECTOR_SIZE
Represents the number of bytes of a sector.
VERSION_2_HEADER
Represents the structure for a V2-style header.