pub enum WriteError {
IoError(Error),
InsufficientHeaderSize,
InvalidNameLength,
}Expand description
Represents a write-related error.
Variants
IoError(Error)
Indicates that a generic I/O error occurred.
InsufficientHeaderSize
Indicates that there is insufficient size in the header to add further entries.
InvalidNameLength
Indicates that the provided name of an entry is longer than 23 characters.